@@ -35,7 +35,6 @@ const stack = new Stack(app, 'test-sns-lambda');
 
 // Definitions
 const props: SnsToLambdaProps = {
-    deployLambda: true,
     lambdaFunctionProps: {
         runtime: lambda.Runtime.NODEJS_12_X,
         handler: 'index.handler',
@@ -63,9 +62,8 @@ new SnsToLambda(scope: Construct, id: string, props: SnsToLambdaProps);
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|deployLambda|`boolean`|Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the `existingLambdaObj` property.|
-|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|An optional, existing Lambda function. This property is required if `deployLambda` is set to false.|
-|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|Optional user-provided props to override the default props for the lambda function|
+|existingLambdaObj?|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.|
+|lambdaFunctionProps?|[`lambda.FunctionProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.FunctionProps.html)|User provided props to override the default props for the Lambda function.|
 |topicProps?|[`sns.TopicProps`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-sns.TopicProps.html)|Optional user provided properties to override the default properties for the SNS topic.|
 |enableEncryption?|`boolean`|Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct.|
 |encryptionKey?|[`kms.Key`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-kms.Key.html)|An optional, imported encryption key to encrypt the SNS topic with.|
@@ -133,7 +131,6 @@ class SnsToLambda(
         scope: aws_cdk.core.Construct,
         id: str,
         *,
-        deploy_lambda: bool,
         enable_encryption: typing.Optional[bool] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
@@ -143,11 +140,10 @@ class SnsToLambda(
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
-        :param deploy_lambda: Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the ``existingLambdaObj`` property. Default: - true
         :param enable_encryption: Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - true (encryption enabled, managed by this CDK app).
         :param encryption_key: An optional, imported encryption key to encrypt the SNS topic with. Default: - not specified.
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
-        :param lambda_function_props: Optional user provided properties to override the default properties for the Lambda function. If ``deploy`` is set to true only then this property is required. Default: - Default properties are used.
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
         :param topic_props: Optional user provided properties to override the default properties for the SNS topic. Default: - Default properties are used.
 
         access:
@@ -158,7 +154,6 @@ class SnsToLambda(
         :summary:: Constructs a new instance of the LambdaToSns class.
         """
         props = SnsToLambdaProps(
-            deploy_lambda=deploy_lambda,
             enable_encryption=enable_encryption,
             encryption_key=encryption_key,
             existing_lambda_obj=existing_lambda_obj,
@@ -183,7 +178,6 @@ class SnsToLambda(
     jsii_type="@aws-solutions-constructs/aws-sns-lambda.SnsToLambdaProps",
     jsii_struct_bases=[],
     name_mapping={
-        "deploy_lambda": "deployLambda",
         "enable_encryption": "enableEncryption",
         "encryption_key": "encryptionKey",
         "existing_lambda_obj": "existingLambdaObj",
@@ -195,7 +189,6 @@ class SnsToLambdaProps:
     def __init__(
         self,
         *,
-        deploy_lambda: bool,
         enable_encryption: typing.Optional[bool] = None,
         encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
@@ -203,19 +196,16 @@ class SnsToLambdaProps:
         topic_props: typing.Any = None,
     ) -> None:
         """
-        :param deploy_lambda: Whether to create a new Lambda function or use an existing Lambda function. If set to false, you must provide an existing function for the ``existingLambdaObj`` property. Default: - true
         :param enable_encryption: Use a KMS Key, either managed by this CDK app, or imported. If importing an encryption key, it must be specified in the encryptionKey property for this construct. Default: - true (encryption enabled, managed by this CDK app).
         :param encryption_key: An optional, imported encryption key to encrypt the SNS topic with. Default: - not specified.
-        :param existing_lambda_obj: Existing instance of Lambda Function object. If ``deploy`` is set to false only then this property is required Default: - None
-        :param lambda_function_props: Optional user provided properties to override the default properties for the Lambda function. If ``deploy`` is set to true only then this property is required. Default: - Default properties are used.
+        :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
+        :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default properties are used.
         :param topic_props: Optional user provided properties to override the default properties for the SNS topic. Default: - Default properties are used.
 
         summary:
         :summary:: The properties for the SnsToLambda class.
         """
-        self._values = {
-            "deploy_lambda": deploy_lambda,
-        }
+        self._values = {}
         if enable_encryption is not None:
             self._values["enable_encryption"] = enable_encryption
         if encryption_key is not None:
@@ -227,17 +217,6 @@ class SnsToLambdaProps:
         if topic_props is not None:
             self._values["topic_props"] = topic_props
 
-    @builtins.property
-    def deploy_lambda(self) -> bool:
-        """Whether to create a new Lambda function or use an existing Lambda function.
-
-        If set to false, you must provide an existing function for the ``existingLambdaObj`` property.
-
-        default
-        :default: - true
-        """
-        return self._values.get("deploy_lambda")
-
     @builtins.property
     def enable_encryption(self) -> typing.Optional[bool]:
         """Use a KMS Key, either managed by this CDK app, or imported.
@@ -261,9 +240,7 @@ class SnsToLambdaProps:
 
     @builtins.property
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
-        """Existing instance of Lambda Function object.
-
-        If ``deploy`` is set to false only then this property is required
+        """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
         default
         :default: - None
@@ -272,9 +249,7 @@ class SnsToLambdaProps:
 
     @builtins.property
     def lambda_function_props(self) -> typing.Any:
-        """Optional user provided properties to override the default properties for the Lambda function.
-
-        If ``deploy`` is set to true only then this property is required.
+        """User provided props to override the default props for the Lambda function.
 
         default
         :default: - Default properties are used.
